@@ -2,17 +2,27 @@
 from numpy import *
 from dtrange import *
 from scisel import *
+from scipy.stats import nanmean
 
 # 1. [2. 3. 4.] 
 #average(
 
 
 # an simpler version of avgcyc
-def avgcyc(x,n):
+def avgcyc(x,n,nanmask=False,stat = mean):
     """ calculate averaged cycle"""
     xout = zeros([n+1]+list(array(x).shape[1:]))
     for ix in range(n):
-        xout[ix] = mean(x[ix::n],axis=0)
+        if nanmask:
+            xtemp = x[ix::n]
+            if type(nanmask) == ndarray:
+                masktemp = nanmask[ix::n]
+            elif nanmask:
+                masktemp = xtemp[:]
+            else:
+                masktemp = zeros_like(xtemp)
+
+            xout[ix] = stat(xtemp[where(isnan(masktemp == False))],axis=0)
     xout[n] = xout[0] 
     return xout
 
